summaryrefslogtreecommitdiffstats
path: root/remoting/client/chromoting_view.h
diff options
context:
space:
mode:
authorgarykac@google.com <garykac@google.com@0039d316-1c4b-4281-b951-d872f2087c98>2010-07-20 00:34:57 +0000
committergarykac@google.com <garykac@google.com@0039d316-1c4b-4281-b951-d872f2087c98>2010-07-20 00:34:57 +0000
commit4d37c874d917cc370e188cfdef05bb629388421a (patch)
tree08f68e3ef47406ae69209f489832fa8f1c76448e /remoting/client/chromoting_view.h
parent0af395eb3fa7d33473b4239a7b637fc6a7ce0e98 (diff)
downloadchromium_src-4d37c874d917cc370e188cfdef05bb629388421a.zip
chromium_src-4d37c874d917cc370e188cfdef05bb629388421a.tar.gz
chromium_src-4d37c874d917cc370e188cfdef05bb629388421a.tar.bz2
Refactor the client code for the X11 version.
Make ChromotingViews responsible for initializing themselves. Move all x11-related code into X11View. Create InputCapturer class manage client input capture. BUG=none TEST=ran Win host + X11 client Review URL: http://codereview.chromium.org/2861047 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@52973 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'remoting/client/chromoting_view.h')
-rw-r--r--remoting/client/chromoting_view.h15
1 files changed, 10 insertions, 5 deletions
diff --git a/remoting/client/chromoting_view.h b/remoting/client/chromoting_view.h
index 503a903..a50b407 100644
--- a/remoting/client/chromoting_view.h
+++ b/remoting/client/chromoting_view.h
@@ -18,6 +18,12 @@ class ChromotingView {
public:
virtual ~ChromotingView() {}
+ // Initialize the common structures for the view.
+ virtual bool Initialize() = 0;
+
+ // Free up resources allocated by this view.
+ virtual void TearDown() = 0;
+
// Tells the ChromotingView to paint the current image on the screen.
// TODO(hclam): Add rects as parameter if needed.
virtual void Paint() = 0;
@@ -34,12 +40,11 @@ class ChromotingView {
// extends past the end of the backing store, it is filled with black.
virtual void SetViewport(int x, int y, int width, int height) = 0;
// Resize the underlying image that is displayed. This should match the size
// of the output from the decoder.
//
- // TODO(ajwong): We need a better name. Look at how Java represents this
- // stuff?
- virtual void SetBackingStoreSize(int width, int height) = 0;
+ // TODO(garykac): This handles only 1 screen. We need multi-screen support.
+ virtual void SetHostScreenSize(int width, int height) = 0;
// Handle the BeginUpdateStream message.
virtual void HandleBeginUpdateStream(HostMessage* msg) = 0;
@@ -34,12 +40,11 @@ class ChromotingView {
// extends past the end of the backing store, it is filled with black.
virtual void SetViewport(int x, int y, int width, int height) = 0;
- // Resize the underlying image that is displayed. This should match the size
- // of the output from the decoder.
+ // Resize the underlying image that contains the host screen buffer.
+ // This should match the size of the output from the decoder.
//